==> leonardo-0.4.0.tgz: leonardo-0.4.0/lib/providers/atom.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import time

import templates.atom as template
from blog import Walker
from web_resource import TopLevelResource


class AtomProvider:
    
    def __init__(self, resource_manager, lfs, config):

        self.resource_manager = resource_manager
        self.lfs              = lfs
        self.config           = config
       
        self.atom_path        = config.atom_path
        self.full_atom_path   = config.full_atom_path
         
       
    def get(self, resource_id, request, main_resource):
    
        if resource_id == self.atom_path:
            return AtomResource(resource_id, self.resource_manager, self.lfs, request, self.config, full=False)
        elif resource_id == self.full_atom_path:
            return AtomResource(resource_id, self.resource_manager, self.lfs, request, self.config, full=True)
        else:
            return None



class AtomResource(TopLevelResource):


    def __init__(self, resource_id, resource_manager, lfs, request, config, full):
        TopLevelResource.__init__(self, resource_id, 'text/xml; charset="utf-8"')
        if full:
            formatter = FullAtomFormatter(resource_manager, config)
        else:
            formatter = AtomFormatter(resource_manager, config)
        walker = Walker(formatter, config.blog_prefix, lfs)
        self.content = walker.all(request, self)
        
        
    def get_content(self):
        return self.content
    
    

class AtomFormatter:


    def __init__(self, resource_manager, config):
    
        self.resource_manager = resource_manager
        
        self.atom_path   = config.atom_path
        self.site_url    = config.site_url
        self.blog_title  = config.blog_title
        self.blog_prefix = config.blog_prefix
        self.blog_author = config.blog_author
        
        self.shown_modified = False
        
        
    def header(self):
        blog_title  = self.blog_title
        blog_url    = self.site_url + self.blog_prefix
        blog_author = self.blog_author
        
        return template.atom_header % locals()


    def footer(self):
        return template.atom_footer % locals()
        

    def no_entries(self):
        return template.atom_no_entries % locals()
        
        
    def entry(self, year, month, day, entry, request, main_resource):
        page_key = "%s/%s/%s/%s/%s" % (self.blog_prefix, year, month, day, entry)
        page = self.resource_manager.get(page_key, request, main_resource)
        iso_time = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime(page.get_lastmod()))
        title = page.get_title()
        html_link = self.site_url + page_key
        
        if not self.shown_modified:
            self.shown_modified = True

            s = template.atom_modified % locals()
        else:
            s = ""
    
        modified = iso_time
        issued = iso_time
            
        s += template.atom_entry % locals()

        return s   



class FullAtomFormatter(AtomFormatter):

        
    def entry(self, year, month, day, entry, request, main_resource):
        page_key = "%s/%s/%s/%s/%s" % (self.blog_prefix, year, month, day, entry)
        page = self.resource_manager.get(page_key, request, main_resource)
        iso_time = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime(page.get_lastmod()))
        title = page.get_title()
        html_link = self.site_url + page_key
                
        if not self.shown_modified:
            self.shown_modified = True
            s = template.atom_modified % locals()
        else:
            s = ""
    
        modified = iso_time
        issued = iso_time
            
        content = page.get_html()
        s += template.atom_full_entry % locals()

        return s

==> leonardo-0.5b1.tgz: leonardo-0.5b1/lib/providers/atom.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import time

import templates.atom as template
from blog import Walker, ALL
from web_resource import TopLevelResource


class AtomProvider:
    

    def __init__(self, resource_manager, lfs, config):

        self.resource_manager = resource_manager
        self.lfs              = lfs
        self.config           = config
       
        self.atom_path          = config.atom_path
        self.full_atom_path     = config.full_atom_path
        self.atom_all_path      = config.atom_all_path
        self.full_atom_all_path = config.full_atom_all_path
        self.atom_recent_count  = config.atom_recent_count
         
       
    def get(self, resource_id, request, main_resource):
    
        if resource_id == self.atom_path:
            return AtomResource(resource_id, self.resource_manager, self.lfs, request, self.config, full=False, number=self.atom_recent_count)
        elif resource_id == self.full_atom_path:
            return AtomResource(resource_id, self.resource_manager, self.lfs, request, self.config, full=True, number=self.atom_recent_count)
        elif resource_id == self.atom_all_path:
            return AtomResource(resource_id, self.resource_manager, self.lfs, request, self.config, full=False, number=ALL)
        elif resource_id == self.full_atom_all_path:
            return AtomResource(resource_id, self.resource_manager, self.lfs, request, self.config, full=True, number=ALL)
        else:
            return None



class AtomResource(TopLevelResource):


    def __init__(self, resource_id, resource_manager, lfs, request, config, full, number):
        TopLevelResource.__init__(self, resource_id, 'text/xml; charset="utf-8"')
        
        if full:
            formatter = FullAtomFormatter(resource_manager, config)
        else:
            formatter = AtomFormatter(resource_manager, config)
        walker = Walker(formatter, config.blog_prefix, lfs)
        if number == ALL:
            self.content = walker.all(request, self)
        else:
            self.content = walker.recent(request, self, number)
        
        
    def get_content(self):
        return self.content
    
    

class AtomFormatter:


    def __init__(self, resource_manager, config):
    
        self.resource_manager = resource_manager
        
        self.atom_path   = config.atom_path
        self.site_url    = config.site_url
        self.blog_title  = config.blog_title
        self.blog_prefix = config.blog_prefix
        self.blog_author = config.blog_author
        
        self.shown_modified = False
        
        
    def header(self):
        blog_title  = self.blog_title
        blog_url    = self.site_url + self.blog_prefix
        blog_author = self.blog_author
        
        return template.atom_header % locals()


    def footer(self):
        return template.atom_footer % locals()
        

    def no_entries(self):
        return template.atom_no_entries % locals()
        
        
    def entry(self, year, month, day, entry, request, main_resource):
        page_key = "%s/%s/%s/%s/%s" % (self.blog_prefix, year, month, day, entry)
        page = self.resource_manager.get(page_key, request, main_resource)
        iso_time = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime(page.get_lastmod()))
        title = page.get_title()
        html_link = self.site_url + page_key
        
        if not self.shown_modified:
            self.shown_modified = True
            s = template.atom_modified % locals()
            # this is the overall feed lastmod, so tell the main resource
            main_resource.lastmod = time.gmtime(page.get_lastmod())
        else:
            s = ""
    
        modified = iso_time
        issued = iso_time
            
        s += template.atom_entry % locals()

        return s   



class FullAtomFormatter(AtomFormatter):

        
    def entry(self, year, month, day, entry, request, main_resource):
        page_key = "%s/%s/%s/%s/%s" % (self.blog_prefix, year, month, day, entry)
        page = self.resource_manager.get(page_key, request, main_resource)
        iso_time = time.strftime("%Y-%m-%dT%H:%M:%SZ", time.gmtime(page.get_lastmod()))
        title = page.get_title()
        html_link = self.site_url + page_key
                
        if not self.shown_modified:
            self.shown_modified = True
            s = template.atom_modified % locals()
            # this is the overall feed lastmod, so tell the main resource
            main_resource.lastmod = time.gmtime(page.get_lastmod())
        else:
            s = ""
    
        modified = iso_time
        issued = iso_time
            
        content = page.get_html()
        s += template.atom_full_entry % locals()

        return s
